pub type DLPackManagedTensorToPyObjectNoSync = Option<unsafe extern "C" fn(tensor: *mut DLManagedTensorVersioned, out_py_object: *mut *mut c_void) -> c_int>;Expand description
\brief Imports a DLManagedTensorVersioned to a PyObject* Tensor/NDArray.
Convert an owning DLManagedTensorVersioned* to the Python tensor of the producer (implementor) library with the correct type.
This function does not perform any stream synchronization.
This function is exposed by the framework through the DLPackExchangeAPI.
\param tensor The DLManagedTensorVersioned to convert the ownership of the tensor is stolen. \param out_py_object The output Python object. \return 0 on success, -1 on failure with a Python exception set.
\sa DLPackExchangeAPI
Aliased Type
pub enum DLPackManagedTensorToPyObjectNoSync {
None,
Some(unsafe extern "C" fn(*mut DLManagedTensorVersioned, *mut *mut c_void) -> i32),
}