#[repr(u32)]pub enum DLDataTypeCode {
Show 18 variants
kDLInt = 0,
kDLUInt = 1,
kDLFloat = 2,
kDLOpaqueHandle = 3,
kDLBfloat = 4,
kDLComplex = 5,
kDLBool = 6,
kDLFloat8_e3m4 = 7,
kDLFloat8_e4m3 = 8,
kDLFloat8_e4m3b11fnuz = 9,
kDLFloat8_e4m3fn = 10,
kDLFloat8_e4m3fnuz = 11,
kDLFloat8_e5m2 = 12,
kDLFloat8_e5m2fnuz = 13,
kDLFloat8_e8m0fnu = 14,
kDLFloat6_e2m3fn = 15,
kDLFloat6_e3m2fn = 16,
kDLFloat4_e2m1fn = 17,
}Expand description
\brief The type code options DLDataType.
Variants
kDLInt = 0
\brief signed integer
kDLUInt = 1
\brief unsigned integer
kDLFloat = 2
\brief IEEE floating point
kDLOpaqueHandle = 3
\brief Opaque handle type, reserved for testing purposes. Frameworks need to agree on the handle data type for the exchange to be well-defined.
kDLBfloat = 4
\brief bfloat16
kDLComplex = 5
\brief complex number (C/C++/Python layout: compact struct per complex number)
kDLBool = 6
\brief boolean
kDLFloat8_e3m4 = 7
\brief FP8 data types
kDLFloat8_e4m3 = 8
\brief FP8 data types
kDLFloat8_e4m3b11fnuz = 9
\brief FP8 data types
kDLFloat8_e4m3fn = 10
\brief FP8 data types
kDLFloat8_e4m3fnuz = 11
\brief FP8 data types
kDLFloat8_e5m2 = 12
\brief FP8 data types
kDLFloat8_e5m2fnuz = 13
\brief FP8 data types
kDLFloat8_e8m0fnu = 14
\brief FP8 data types
kDLFloat6_e2m3fn = 15
\brief FP6 data types Setting bits != 6 is currently unspecified, and the producer must ensure it is set while the consumer must stop importing if the value is unexpected.
kDLFloat6_e3m2fn = 16
\brief FP6 data types Setting bits != 6 is currently unspecified, and the producer must ensure it is set while the consumer must stop importing if the value is unexpected.
kDLFloat4_e2m1fn = 17
\brief FP4 data types Setting bits != 4 is currently unspecified, and the producer must ensure it is set while the consumer must stop importing if the value is unexpected.