#[repr(C)]pub struct DLManagedTensor {
pub dl_tensor: DLTensor,
pub manager_ctx: *mut c_void,
pub deleter: Option<unsafe extern "C" fn(self_: *mut DLManagedTensor)>,
}Expand description
\brief C Tensor object, manage memory of DLTensor. This data structure is intended to facilitate the borrowing of DLTensor by another framework. It is not meant to transfer the tensor. When the borrowing framework doesn’t need the tensor, it should call the deleter to notify the host that the resource is no longer needed.
\note This data structure is used as Legacy DLManagedTensor in DLPack exchange and is deprecated after DLPack v0.8 Use DLManagedTensorVersioned instead. This data structure may get renamed or deleted in future versions.
\sa DLManagedTensorVersioned
Fields
dl_tensor: DLTensor\brief DLTensor which is being memory managed
manager_ctx: *mut c_void\brief the context of the original host framework of DLManagedTensor in which DLManagedTensor is used in the framework. It can also be NULL.
deleter: Option<unsafe extern "C" fn(self_: *mut DLManagedTensor)>\brief Destructor - this should be called to destruct the manager_ctx which backs the DLManagedTensor. It can be NULL if there is no way for the caller to provide a reasonable destructor. The destructor deletes the argument self as well.