#[repr(C)]pub struct DLManagedTensorVersioned {
pub version: DLPackVersion,
pub manager_ctx: *mut c_void,
pub deleter: Option<unsafe extern "C" fn(self_: *mut DLManagedTensorVersioned)>,
pub flags: u64,
pub dl_tensor: DLTensor,
}Expand description
\brief A versioned and managed C Tensor object, manage memory of DLTensor.
This data structure is intended to facilitate the borrowing of DLTensor by another framework. It is not meant to transfer the tensor. When the borrowing framework doesn’t need the tensor, it should call the deleter to notify the host that the resource is no longer needed.
\note This is the current standard DLPack exchange data structure.
Fields
version: DLPackVersion\brief The API and ABI version of the current managed Tensor
manager_ctx: *mut c_void\brief the context of the original host framework.
Stores DLManagedTensorVersioned is used in the framework. It can also be NULL.
deleter: Option<unsafe extern "C" fn(self_: *mut DLManagedTensorVersioned)>\brief Destructor.
This should be called to destruct manager_ctx which holds the DLManagedTensorVersioned. It can be NULL if there is no way for the caller to provide a reasonable destructor. The destructor deletes the argument self as well.
flags: u64\brief Additional bitmask flags information about the tensor.
By default the flags should be set to 0.
\note Future ABI changes should keep everything until this field stable, to ensure that deleter can be correctly called.
\sa DLPACK_FLAG_BITMASK_READ_ONLY \sa DLPACK_FLAG_BITMASK_IS_COPIED
dl_tensor: DLTensor\brief DLTensor which is being memory managed