DLPackExchangeAPIHeader

Struct DLPackExchangeAPIHeader 

#[repr(C)]
pub struct DLPackExchangeAPIHeader { pub version: DLPackVersion, pub prev_api: *mut DLPackExchangeAPIHeader, }
\brief DLPackExchangeAPI stable header. \sa DLPackExchangeAPI

Fields

version: DLPackVersion

\brief The provided DLPack version the consumer must check major version compatibility before using this struct.

prev_api: *mut DLPackExchangeAPIHeader

\brief Optional pointer to an older DLPackExchangeAPI in the chain.

It must be NULL if the framework does not support older versions. If the current major version is larger than the one supported by the consumer, the consumer may walk this to find an earlier supported version.

\sa DLPackExchangeAPI